Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(296)

Unified Diff: extensions/common/switches.cc

Issue 820513002: Renamed WorkerFrame to SurfaceWorker (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed tests Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « extensions/common/switches.h ('k') | extensions/extensions.gyp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: extensions/common/switches.cc
diff --git a/extensions/common/switches.cc b/extensions/common/switches.cc
index 849546bde7bdcab1d28ba911eb0aa36ca0260800..fcc6f4990b11537ba1afcd7f470c64a7f969254c 100644
--- a/extensions/common/switches.cc
+++ b/extensions/common/switches.cc
@@ -24,8 +24,8 @@ const char kDisableExtensionInfoDialog[] = "disable-extension-info-dialog";
// a new tab.
const char kEmbeddedExtensionOptions[] = "embedded-extension-options";
-// Enables the WorkerFrame experiment.
-const char kWorkerFrame[] = "worker-frame";
+// Enables the SurfaceWorker experiment.
+const char kSurfaceWorker[] = "surface-worker";
// Show apps windows after the first paint. Windows will be shown significantly
// later for heavy apps loading resources synchronously but it will be
@@ -40,8 +40,8 @@ const char kEnableAppWindowControls[] = "enable-app-window-controls";
const char kEnableEmbeddedExtensionOptions[] =
"enable-embedded-extension-options";
-// Enables the experimental feature <workerframe>.
-const char kEnableWorkerFrame[] = "enable-worker-frame";
+// Enables the experimental feature SurfaceWorker.
+const char kEnableSurfaceWorker[] = "enable-surface-worker";
// Enables extension APIs that are in development.
const char kEnableExperimentalExtensionApis[] =
« no previous file with comments | « extensions/common/switches.h ('k') | extensions/extensions.gyp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698